;;; DO NOT MODIFY THIS FILE
(if (featurep 'edebug-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "edebug/_pkg.el")

(package-provide 'edebug :version 1.22 :author-version "No-Upstream-Ver" :type 'regular)

;;;***

;;;### (autoloads (edebug-eval-top-level-form def-edebug-spec) "edebug" "edebug/edebug.el")

(defcustom edebug-all-defs nil "*If non-nil, evaluation of any defining forms will instrument for Edebug.\nThis applies to `eval-defun', `eval-region', `eval-buffer', and\n`eval-current-buffer'.  `eval-region' is also called by\n`eval-last-sexp', and `eval-print-last-sexp'.\n\nYou can use the command `edebug-all-defs' to toggle the value of this\nvariable.  You may wish to make it local to each buffer with\n(make-local-variable 'edebug-all-defs) in your\n`emacs-lisp-mode-hook'." :type 'boolean :group 'edebug)

(defcustom edebug-all-forms nil "*Non-nil evaluation of all forms will instrument for Edebug.\nThis doesn't apply to loading or evaluations in the minibuffer.\nUse the command `edebug-all-forms' to toggle the value of this option." :type 'boolean :group 'edebug)

(autoload 'def-edebug-spec "edebug" "\
Set the `edebug-form-spec' property of SYMBOL according to SPEC.
Both SYMBOL and SPEC are unevaluated. The SPEC can be 0, t, a symbol
\(naming a function), or a list." nil 'macro)

(defalias 'edebug-defun 'edebug-eval-top-level-form)

(autoload 'edebug-eval-top-level-form "edebug" "\
Evaluate the top level form point is in, stepping through with Edebug.
This is like `eval-defun' except that it steps the code for Edebug
before evaluating it.  It displays the value in the echo area
using `eval-expression' (which see).

If you do this on a function definition
such as a defun or defmacro, it defines the function and instruments
its definition for Edebug, so it will do Edebug stepping when called
later.  It displays `Edebug: FUNCTION' in the echo area to indicate
that FUNCTION is now instrumented for Edebug.

If the current defun is actually a call to `defvar' or `defcustom',
evaluating it this way resets the variable using its initial value
expression even if the variable already has some other value.
\(Normally `defvar' and `defcustom' do not alter the value if there
already is one.)" t nil)

;;;***

(provide 'edebug-autoloads)
